@@ -1,6 +1,8 @@
 # plot method for Jackknife smacof
 
-plot.smacofJK <- function(x, plot.dim = c(1,2), hclpar = list(c = 50, l = 70), col.p, col.l, plot.lines = TRUE, main, xlab, ylab, xlim, ylim, asp = 1, ...)
+plot.smacofJK <- function(x, plot.dim = c(1,2), hclpar = list(c = 50, l = 70), col.p, col.l, 
+                          plot.lines = TRUE, legend = FALSE, inset = c(-0.2, 0), cex.legend = 0.7,
+                          main, xlab, ylab, xlim, ylim, asp = 1, ...)
 {
 # x ... object of class smacofJK
   n <- x$nobj
@@ -11,7 +13,8 @@ plot.smacofJK <- function(x, plot.dim = c(1,2), hclpar = list(c = 50, l = 70), c
     hclcolors <- col.p
     hclcolors1 <- rep(col.l, n)
   }
-
+  if (legend) hclcolors1 <- hclcolors
+  
   x1 <- plot.dim[1]
   y1 <- plot.dim[2]
   if (missing(main)) main <- paste("SMACOF Jackknife Plot") else main <- main
@@ -29,19 +32,26 @@ plot.smacofJK <- function(x, plot.dim = c(1,2), hclpar = list(c = 50, l = 70), c
   if (missing(xlim)) xlim <- range(xcoor)
   if (missing(ylim)) ylim <- range(ycoor)
   
-  plot(x0[, 1:2], type = "n", xlab = xlab, ylab = ylab, main = main, col = hclcolors, xlim = xlim, ylim = ylim, asp = asp,...)
+  if (legend) op <- par(mar = c(5.1, 4.1, 4.1, 8.1), xpd = TRUE)
+  plot(x0[, 1:2], type = "n", xlab = xlab, ylab = ylab, main = main, col = hclcolors, xlim = xlim, ylim = ylim, asp = asp, ...)
   points(y0[, 1:2], col = hclcolors1, cex = 0.6, pch = 16)
 	
   if (plot.lines) {
 	 for (i in 1:n) {
 	   for (j in 1:n) {
-	    #text (yy[j, 1, i], yy[j, 2, i], as.character(i), cex = 0.5, pos = ppos, col = hclcolors[j])
-      points(yy[j, 1, i], yy[j, 2, i], cex = 0.2, col = hclcolors1[j], pch = 20)
+	    points(yy[j, 1, i], yy[j, 2, i], cex = 0.2, col = hclcolors1[j], pch = 20)
 	    lines(matrix (c (y0[j, 1:2], yy[j, 1:2, i]), 2, 2, byrow=TRUE), col = hclcolors1[j], lty = 1, lwd = 0.5)
 	   }
 	 }
   }
-  text(x0[, 1:2], rownames(x$smacof.conf), cex = 0.8, col = hclcolors)
+  
+  if (!legend) {
+    text(x0[, 1:2], rownames(x$smacof.conf), cex = 0.8, col = hclcolors) 
+  } else {
+    legend("topright", legend = rownames(x$smacof.conf), pch = 16, col = hclcolors1, 
+           title = "Objects", cex = cex.legend, inset = inset)
+    par(op)
+  }
 }
 
 
